@@ -7,3 +7,7 @@ from pyslz.pyslz import postgres_upsert
 from pyslz.pyslz import postgres_insert_batch
 from pyslz.pyslz import postgres_update_with_df
 from pyslz.pyslz import postgres_insert_batch_without_conflict
+from pyslz.pyslz import postgres_insert_batch_without_conflict_v2
+from pyslz.pyslz import postgres_upsert_v2
+from pyslz.pyslz import postgres_insert_batch_v2
+from pyslz.pyslz import postgres_update_with_df_v2
\ No newline at end of file
